==> haskell-attoparsec-iso8601-1.0.2.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 attoparsec-iso8601
version:              1.0.2.1
visibility:           public
id:                   attoparsec-iso8601-1.0.2.1-6OZJxftI3VbHhnu3qZTvuz
key:                  attoparsec-iso8601-1.0.2.1-6OZJxftI3VbHhnu3qZTvuz
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  5a05fd9614bad751561cab47d16e6716
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/attoparsec-iso8601-1.0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/attoparsec-iso8601-1.0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.0.2.1-6OZJxftI3VbHhnu3qZTvuz
depends:
    attoparsec-0.14.4-3b5hJmAVxMZ2YoY0FeNqg3 base-4.15.1.0
    base-compat-batteries-0.12.1-DYcn9hPoSpqCCc3vc2Plqi text-1.2.5.0
    time-1.9.3 time-compat-1.9.6.1-BsM2J2VCXkOGFoYVtCIwOq

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.0.2.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 attoparsec-iso8601
version:              1.0.2.1
visibility:           public
id:                   attoparsec-iso8601-1.0.2.1-52DNiwFXw4cGn73BIdu06G
key:                  attoparsec-iso8601-1.0.2.1-52DNiwFXw4cGn73BIdu06G
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  23a31fa5925a161cc22ac688fb94102e
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/attoparsec-iso8601-1.0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/attoparsec-iso8601-1.0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.0.2.1-52DNiwFXw4cGn73BIdu06G
depends:
    attoparsec-0.14.4-LMP3CNm1bKfAGlDkrWrjI6 base-4.15.1.0
    base-compat-batteries-0.12.1-AWDo7lv7L6cITvBNZzqc78 text-1.2.5.0
    time-1.9.3 time-compat-1.9.6.1-6FHLUZCzVyrDn7CI58aMKC

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
